<?php
/**
 * mobile-friendly functions and definitions
 *
 * @package mobile-friendly
 */

global $class_name;
/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

/**
 * Define constants.
 */
define( 'MOBILE_FRINEDLY_THEME_VERSION', '3.0.0' );


if ( ! function_exists( 'mobile_friendly_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
	function mobile_friendly_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on mobile-friendly, use a find and replace
		 * to change 'mobile-friendly' to the name of your theme in all the template files
		 */
		load_theme_textdomain( 'mobile-friendly', get_stylesheet_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'primary' => __( 'Primary Menu', 'mobile-friendly' ),
			)
		);

		// @link http://codex.wordpress.org/Function_Reference/unregister_nav_menu
		unregister_nav_menu( 'header-menu' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		/*
		 * Enable support for Post Formats.
		 * See http://codex.wordpress.org/Post_Formats
		 */
		add_theme_support(
			'post-formats',
			array(
				'aside',
				'image',
				'video',
				'quote',
				'link',
			)
		);

	}
endif; // mobile_friendly_setup.
add_action( 'after_setup_theme', 'mobile_friendly_setup', 99 );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function mobile_friendly_widgets_init() {
	global $class_name;
	register_sidebar(
		array(
			'name'          => __( 'Left Sidebar', 'mobile-friendly' ),
			'id'            => 'sidebar-1',
			'description'   => __('This widget is located in the left off-screen sidebar, underneath the menu.', 'mobile-friendly'),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);
	register_sidebar(
		array(
			'name'          => __( 'Right Sidebar', 'mobile-friendly' ),
			'id'            => 'right-sidebar',
			'description'   => __('This widget is located in the right off-screen sidebar.', 'mobile-friendly'),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);
	register_sidebar(
		array(
			'name'          => __( 'First Homepage Widget', 'mobile-friendly' ),
			'id'            => 'homepage-first',
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);
	register_sidebar(
		array(
			'name'          => __( 'Second Homepage Widget', 'mobile-friendly' ),
			'id'            => 'homepage-second',
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);
	register_sidebar(
		array(
			'name'          => __( 'Third Homepage Widget', 'mobile-friendly' ),
			'id'            => 'homepage-third',
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);
	register_sidebar(
		array(
			'name'          => __( 'Footer Widget', 'mobile-friendly' ),
			'id'            => 'footer',
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="' . $class_name . '">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h5 class="widget-title">',
			'after_title'   => '</h5>',
		)
	);

}
add_action( 'widgets_init', 'mobile_friendly_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function mobile_friendly_scripts() {

	$parent_style = 'responsive-style';

	wp_enqueue_style( $parent_style, get_template_directory_uri() . '/core/css/style.css' );

	wp_enqueue_style(
		'mobile-friendly-style',
		get_stylesheet_directory_uri() . '/style.css',
		array( $parent_style ),
		wp_get_theme()->get( 'Version' )
	);

	wp_enqueue_style( 'mobile-friendly-icons', get_stylesheet_directory_uri() . '/fonts/mobilefirst.css', array(), wp_get_theme()->get( 'Version' ) );

	wp_enqueue_style( 'mobile-friendly-animate', get_stylesheet_directory_uri() . '/css/animate.css', array(), wp_get_theme()->get( 'Version' ) );

	wp_enqueue_script( 'mobile-friendly-wow', get_stylesheet_directory_uri() . '/js/wow.min.js', array( 'jquery' ), '1.0.2', true );

	wp_enqueue_script( 'mobile-friendly-navigation', get_stylesheet_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'mobile-friendly-bigslide', get_stylesheet_directory_uri() . '/js/bigslide.js', array( 'jquery' ), '0.5.0', true );

	wp_enqueue_script( 'mobile-friendly-jsfunctions', get_stylesheet_directory_uri() . '/js/functions.js', array(), MOBILE_FRINEDLY_THEME_VERSION, true );

	wp_enqueue_style( 'mobile-friendly-bootstrap', get_stylesheet_directory_uri() . '/inc/bootstrap/css/bootstrap.min.css', false, '3.3.4' );

	wp_enqueue_script( 'mobile-friendly-bootstrap-js', get_stylesheet_directory_uri() . '/inc/bootstrap/js/bootstrap.min.js', array( 'jquery' ), '3.3.4', true );

	wp_enqueue_script( 'mobile-friendly-skip-link-focus-fix', get_stylesheet_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	wp_enqueue_style( 'mobile-friendly-fontawesome-style', get_stylesheet_directory_uri() . '/css/font-awesome.min.css', false, '4.7.0' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'mobile_friendly_scripts', 99 );

/**
 * Custom template tags for this theme.
 */
require get_stylesheet_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_stylesheet_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_stylesheet_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_stylesheet_directory() . '/inc/jetpack.php';

require get_stylesheet_directory() . '/widget.php';

function mobile_friendly_footer_sidebar_params( $params ) {
	$sidebar_id = $params[0]['id'];
	if ( $sidebar_id == 'footer' ) {
	$total_widgets = wp_get_sidebars_widgets();
	$count = count($total_widgets[$sidebar_id]);
	$params[0]['before_widget'] = str_replace('class="', 'class="span' . floor(12 / $count) . ' ', $params[0]['before_widget']);
	}
    return $params;
}
add_filter( 'dynamic_sidebar_params', 'mobile_friendly_footer_sidebar_params' );

function mobile_friendly_featured_image() {
	global $post;
	if( has_post_thumbnail() ): ?>
			<div class="featured-image">
				<a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'mobile-friendly' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark">
					<?php the_post_thumbnail( apply_filters( 'cyberchimps_post_thumbnail_size', 'thumbnail' ) ); ?>
				</a>
			</div>
		<?php    endif;

}

//Enqueue google font
function mobile_friendly_google_fonts() {
	$query_args = array(
		'family' => 'Source+Sans+Pro:400,300,700',
		'subset' => 'latin,latin-ext',
	);
	wp_register_style( 'google_fonts', add_query_arg( $query_args, "//fonts.googleapis.com/css" ), array(), null );
}

add_action( 'wp_enqueue_scripts', 'mobile_friendly_google_fonts' );

function mobile_friendly_customize_edit_links( $wp_customize ) {


	$wp_customize->selective_refresh->add_partial(
		'blogname',
		array(
			'selector' => '.site-title a'
		)
	);

	$wp_customize->selective_refresh->add_partial(
		'blogdescription',
		array(
			'selector' => '.site-description'
		)
	);

	$wp_customize->selective_refresh->add_partial( 'cyberchimps_options[custom_logo]', array(
		'selector' => '#logo'
	) );

	$wp_customize->selective_refresh->add_partial( 'cyberchimps_options[theme_backgrounds]', array(
		'selector' => '#social'
	) );

	$wp_customize->selective_refresh->add_partial( 'cyberchimps_options[searchbar]', array(
		'selector' => '#navigation #searchform'
	) );

	$wp_customize->selective_refresh->add_partial( 'cyberchimps_options[footer_copyright_text]', array(
		'selector' => '#copyright'
	) );

	$wp_customize->selective_refresh->add_partial( 'nav_menu_locations[primary]', array(
		'selector' => '.main-navigation'
	) );

	$wp_customize->selective_refresh->add_partial( 'nav_menu_locations[secondary]', array(
		'selector' => '.second-navigation'
	) );

	$wp_customize->selective_refresh->add_partial( 'cyberchimps_options[blog_title]', array(
		'selector' => '.page-title'
	) );

	$wp_customize->selective_refresh->add_partial( 'cyberchimps_options[footer_show_toggle]', array(
		'selector' => '#footer_wrapper'
	) );

	$wp_customize->selective_refresh->add_partial( 'hero_heading', array(
		'selector' => '.hero-content h1'
	) );

	$wp_customize->selective_refresh->add_partial( 'hero_secondary', array(
		'selector' => '.hero-content h2'
	) );

	$wp_customize->selective_refresh->add_partial( 'hero_button_text', array(
		'selector' => '.hero-content .button p'
	) );

	$wp_customize->selective_refresh->add_partial( 'hero_image', array(
		'selector' => '.achimps'
	) );

	$wp_customize->selective_refresh->add_partial( 'cta_text', array(
		'selector' => '.cta-content h2'
	) );

	$wp_customize->selective_refresh->add_partial( 'cta_button_text', array(
		'selector' => '.first-button p'
	) );

	$wp_customize->selective_refresh->add_partial( 'cta_second_button_text', array(
		'selector' => '.second-button p'
	) );

	$wp_customize->selective_refresh->add_partial( 'cta_image', array(
		'selector' => '.cta-content .featured-image'
	) );

	$wp_customize->selective_refresh->add_partial( 'teaser_text', array(
		'selector' => '.teaser-content h3'
	) );

	$wp_customize->selective_refresh->add_partial( 'copyright', array(
		'selector' => '.copyright'
	) );

	$wp_customize->selective_refresh->add_partial( 'site_info', array(
		'selector' => '.site-info-inner'
	) );

}
add_action( 'customize_register', 'mobile_friendly_customize_edit_links' );
add_theme_support( 'customize-selective-refresh-widgets' );

add_action( 'admin_notices', 'mobile_friendly_admin_notices' );
function mobile_friendly_admin_notices()
{
	$admin_check_screen = get_admin_page_title();

	if( !class_exists('SlideDeckPlugin') )
	{
	$plugin='slidedeck/slidedeck.php';
	$slug = 'slidedeck';
	$installed_plugins = get_plugins();

	 if ( $admin_check_screen == 'Manage Themes' || $admin_check_screen == 'Theme Options Page' )
	{
		?>
		<div class="notice notice-info is-dismissible" style="margin-top:15px;">
		<p>
			<?php if( isset( $installed_plugins[$plugin] ) )
			{
			?>
				 <a href="<?php echo admin_url( 'plugins.php' ); ?>">Activate the SlideDeck Lite plugin</a>
			 <?php
			}
			else
			{
			 ?>
			 <a href="<?php echo wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=' . $slug ), 'install-plugin_' . $slug ); ?>">Install the SlideDeck Lite plugin</a>
			 <?php } ?>

		</p>
		</div>
		<?php
	}
	}

	if( !class_exists('WPForms') )
	{
	$plugin = 'wpforms-lite/wpforms.php';
	$slug = 'wpforms-lite';
	$installed_plugins = get_plugins();
	 if ( $admin_check_screen == 'Manage Themes' || $admin_check_screen == 'Theme Options Page' )
	{
		?>
		<div class="notice notice-info is-dismissible" style="margin-top:15px;">
		<p>
			<?php if( isset( $installed_plugins[$plugin] ) )
			{
			?>
				 <a href="<?php echo admin_url( 'plugins.php' ); ?>">Activate the WPForms Lite plugin</a>
			 <?php
			}
			else
			{
			 ?>
	 		 <a href="<?php echo wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=' . $slug ), 'install-plugin_' . $slug ); ?>">Install the WP Forms Lite plugin</a>
			 <?php } ?>
		</p>
		</div>
		<?php
	}
	}

	if ( $admin_check_screen == 'Manage Themes' || $admin_check_screen == 'Theme Options Page' ) {
	?>
		<div class="notice notice-success is-dismissible">
				<b><p>Liked this theme? <a href="https://wordpress.org/support/theme/mobile-friendly/reviews/#new-post" target="_blank">Leave us</a> a ***** rating. Thank you! </p></b>
		</div>
		<?php
	}

}



add_action( 'add_meta_boxes', 'mobile_friendly_team_add_meta_box' );

function mobile_friendly_team_add_meta_box() {
	global $post;

	add_meta_box( 'mobile_friendly_team_meta_box', 'Team Section Options', 'mobile_friendly_team_meta_box_cb', 'post', 'normal', 'high' );
}
function mobile_friendly_team_meta_box_cb() {
	global $post;
	$values = get_post_custom( $post->ID );
	$mobile_friendly_meta_box_designation = isset( $values['mobile_friendly_meta_box_designation'] ) ? $values['mobile_friendly_meta_box_designation'][0] : '';
	$mobile_friendly_meta_box_facebook = isset( $values['mobile_friendly_meta_box_facebook'] ) ? $values['mobile_friendly_meta_box_facebook'][0] : '';
	$mobile_friendly_meta_box_twitter = isset( $values['mobile_friendly_meta_box_twitter'] ) ? $values['mobile_friendly_meta_box_twitter'][0] : '';
	$mobile_friendly_meta_box_googleplus = isset( $values['mobile_friendly_meta_box_googleplus'] ) ? $values['mobile_friendly_meta_box_googleplus'][0] : '';
	$mobile_friendly_meta_box_linkedin = isset( $values['mobile_friendly_meta_box_text_linkedin'] ) ? $values['mobile_friendly_meta_box_text_linkedin'][0] : '';

	wp_nonce_field( 'mobile_friendly_meta_box_nonce', 'meta_box_nonce' );
	?>
	<p><?php echo esc_html(__("To use this post for front page's team section, please enter below details:",'mobile-friendly')); ?>
    </p>
	<p>
        <label for="mobile_friendly_meta_box_designation"><?php echo esc_html(__('Member designation','mobile-friendly')); ?></label>
        <input type="text" name="mobile_friendly_meta_box_designation" id="mobile_friendly_meta_box_designationion" value="<?php echo $mobile_friendly_meta_box_designation; ?>" />
    </p>
	<p>
        <label for="mobile_friendly_meta_box_facebook"><?php echo esc_html(__('Facebook Link','mobile-friendly')); ?></label>
        <input type="text" name="mobile_friendly_meta_box_facebook" id="mobile_friendly_meta_box_facebook" value="<?php echo $mobile_friendly_meta_box_facebook; ?>" />
    </p>
	<p>
        <label for="mobile_friendly_meta_box_twitter"><?php echo esc_html(__('Twitter Link','mobile-friendly')); ?></label>
        <input type="text" name="mobile_friendly_meta_box_twitter" id="mobile_friendly_meta_box_twitter" value="<?php echo $mobile_friendly_meta_box_twitter; ?>" />
    </p>
	<p>
        <label for="mobile_friendly_meta_box_googleplus"><?php echo esc_html(__('GooglePlus Link','mobile-friendly')); ?></label>
        <input type="text" name="mobile_friendly_meta_box_googleplus" id="mobile_friendly_meta_box_googleplus" value="<?php echo $mobile_friendly_meta_box_googleplus; ?>" />
    </p>
	<p>
        <label for="mobile_friendly_meta_box_text_linkedin"><?php echo esc_html(__('LinkedIn Link','mobile-friendly')); ?></label>
        <input type="text" name="mobile_friendly_meta_box_text_linkedin" id="mobile_friendly_meta_box_text_linkedin" value="<?php echo $mobile_friendly_meta_box_linkedin; ?>" />
    </p>

<?php
}
add_action( 'save_post', 'mobile_friendly_team_meta_box_save' );
function mobile_friendly_team_meta_box_save( $post_id )
{
	$allowed = array(
        'a' => array( // on allow a tags
            'href' => array() // and those anchors can only have href attribute
        )
    );

	if( isset( $_POST['mobile_friendly_meta_box_designation'] ) )
        update_post_meta( $post_id, 'mobile_friendly_meta_box_designation', wp_kses( $_POST['mobile_friendly_meta_box_designation'], $allowed ) );
	if( isset( $_POST['mobile_friendly_meta_box_facebook'] ) )
        update_post_meta( $post_id, 'mobile_friendly_meta_box_facebook', wp_kses( $_POST['mobile_friendly_meta_box_facebook'], $allowed ) );
	if( isset( $_POST['mobile_friendly_meta_box_twitter'] ) )
        update_post_meta( $post_id, 'mobile_friendly_meta_box_twitter', wp_kses( $_POST['mobile_friendly_meta_box_twitter'], $allowed ) );
	if( isset( $_POST['mobile_friendly_meta_box_googleplus'] ) )
        update_post_meta( $post_id, 'mobile_friendly_meta_box_googleplus', wp_kses( $_POST['mobile_friendly_meta_box_googleplus'], $allowed ) );
	if( isset( $_POST['mobile_friendly_meta_box_text_linkedin'] ) )
        update_post_meta( $post_id, 'mobile_friendly_meta_box_text_linkedin', wp_kses( $_POST['mobile_friendly_meta_box_text_linkedin'], $allowed ) );
}


if( !function_exists('mobile_friendly_get_attachment_id_from_url') ) :
function mobile_friendly_get_attachment_id_from_url( $attachment_url = '' ) {
	global $wpdb;
	$attachment_id = false;
	// If there is no url, return.
	if ( '' == $attachment_url )
		return;
	// Get the upload directory paths
	$upload_dir_paths = wp_upload_dir();
	// Make sure the upload path base directory exists in the attachment URL, to verify that we're working with a media library image
	if ( false !== strpos( $attachment_url, $upload_dir_paths['baseurl'] ) ) {
		// If this is the URL of an auto-generated thumbnail, get the URL of the original image
		$attachment_url = preg_replace( '/-\d+x\d+(?=\.(jpg|jpeg|png|gif)$)/i', '', $attachment_url );
		// Remove the upload path base directory from the attachment URL
		$attachment_url = str_replace( $upload_dir_paths['baseurl'] . '/', '', $attachment_url );
		// Finally, run a custom database query to get the attachment ID from the modified attachment URL
		$attachment_id = $wpdb->get_var( $wpdb->prepare( "SELECT wposts.ID FROM $wpdb->posts wposts, $wpdb->postmeta wpostmeta WHERE wposts.ID = wpostmeta.post_id AND wpostmeta.meta_key = '_wp_attached_file' AND wpostmeta.meta_value = '%s' AND wposts.post_type = 'attachment'", $attachment_url ) );
	}
	return $attachment_id;
}
endif;

add_action( 'after_setup_theme', 'mobile_friendly_remove_starter_content', 99 );
function mobile_friendly_remove_starter_content() {
	require_once get_template_directory() . '/core/includes/starter-content.php';
	remove_theme_support( 'starter-content', responsive_get_starter_content() );
}

/**
 * This function overrides customizer defaults of Responsive theme
 *
 * @param array $theme_options Theme Options.
 * @return mixed
 */
function mobile_friendly_override_theme_defaults( $theme_options ) {
	$theme_options['background_color'] = '#fff';
	$theme_options['h2_text']          = '#fff';
	$theme_options['h3_text']          = '#333333';

	return $theme_options;
}

add_filter( 'responsive_theme_defaults', 'mobile_friendly_override_theme_defaults', 10, 1 );

/**
 * This function overrides typography selectors of Responsive theme
 *
 * @param array $selector_array Selector Array.
 * @return mixed
 */
function mobile_friendly_override_typography_selectors( $selector_array ) {
    $selector_array['meta']=".entry-header .entry-meta";
    $selector_array['header_site_title']=".site-header .header-content .site-branding .site-title";
    $selector_array['header_site_title2']=".site-header .header-content .site-branding .site-title a";
    $selector_array['header_menu']="nav.main-panel.main-navigation .menu > ul li a, nav.main-panel.main-navigation ul.menu li a";
    $selector_array['sidebar']=".panel-right.widget-area ul a";
    return $selector_array;
}

add_filter( 'responsive_typography_selectors', 'mobile_friendly_override_typography_selectors', 10, 1 );


/**
 * Outputs the custom styles for the theme.
 *
 * @return void
 */
function mobile_friendly_customizer_styles() {

	$custom_css = '';

	// Sidebar Color.
	$mf_sidebar_headings_color   = esc_html( get_theme_mod( 'responsive_sidebar_headings_color', get_theme_mod( 'responsive_h4_text_color', '#333333' ) ) );
	$mf_sidebar_background_color = esc_html( get_theme_mod( 'responsive_sidebar_background_color', get_theme_mod( 'responsive_box_background_color', '#222' ) ) );
	$mf_sidebar_text_color       = esc_html( get_theme_mod( 'responsive_sidebar_text_color', get_theme_mod( 'responsive_body_text_color', '#ffffff' ) ) );
	$mf_sidebar_link_color       = esc_html( get_theme_mod( 'responsive_sidebar_link_color', get_theme_mod( 'responsive_link_color', '#1eaedb' ) ) );
	$mf_sidebar_link_hover_color = esc_html( get_theme_mod( 'responsive_sidebar_link_hover_color', get_theme_mod( 'responsive_link_hover_color', '#10659C' ) ) );
	$mf_header_menu_link_color   = esc_html( get_theme_mod( 'responsive_header_menu_link_color' ) );
	$mf_heading1_text_color      = esc_html( get_theme_mod( 'responsive_h1_text_color', '#fff' ) );
	$mf_heading2_text_color      = esc_html( get_theme_mod( 'responsive_h2_text_color', '#fff' ) );
	$mf_heading3_text_color      = esc_html( get_theme_mod( 'responsive_h3_text_color', '#333333' ) );


	$body_text_color = esc_html( get_theme_mod( 'responsive_body_text_color', '#333333' ) );

	$link_color       = esc_html( get_theme_mod( 'responsive_link_color', '#0066CC' ) );
	$link_hover_color = esc_html( get_theme_mod( 'responsive_link_hover_color', '#10659C' ) );

	$button_color              = esc_html( get_theme_mod( 'responsive_button_color', '#0066CC' ) );
	$button_hover_color        = esc_html( get_theme_mod( 'responsive_button_hover_color', '#10659C' ) );
	$button_text_color         = esc_html( get_theme_mod( 'responsive_button_text_color', '#FFFFFF' ) );
	$button_hover_text_color   = esc_html( get_theme_mod( 'responsive_button_hover_text_color', '#FFFFFF' ) );
	$button_border_color       = esc_html( get_theme_mod( 'responsive_button_border_color', '#10659C' ) );
	$button_hover_border_color = esc_html( get_theme_mod( 'responsive_button_hover_border_color', '#0066CC' ) );

	$buttons_padding_right  = esc_html( get_theme_mod( 'responsive_buttons_right_padding', 10 ) );
	$buttons_padding_left   = esc_html( get_theme_mod( 'responsive_buttons_left_padding', 10 ) );
	$buttons_padding_top    = esc_html( get_theme_mod( 'responsive_buttons_top_padding', 10 ) );
	$buttons_padding_bottom = esc_html( get_theme_mod( 'responsive_buttons_bottom_padding', 10 ) );

	$buttons_tablet_padding_right  = esc_html( get_theme_mod( 'responsive_buttons_tablet_right_padding', 10 ) );
	$buttons_tablet_padding_left   = esc_html( get_theme_mod( 'responsive_buttons_tablet_left_padding', 10 ) );
	$buttons_tablet_padding_top    = esc_html( get_theme_mod( 'responsive_buttons_tablet_top_padding', 10 ) );
	$buttons_tablet_padding_bottom = esc_html( get_theme_mod( 'responsive_buttons_tablet_bottom_padding', 10 ) );

	$buttons_mobile_padding_right  = esc_html( get_theme_mod( 'responsive_buttons_mobile_right_padding', 10 ) );
	$buttons_mobile_padding_left   = esc_html( get_theme_mod( 'responsive_buttons_mobile_left_padding', 10 ) );
	$buttons_mobile_padding_top    = esc_html( get_theme_mod( 'responsive_buttons_mobile_top_padding', 10 ) );
	$buttons_mobile_padding_bottom = esc_html( get_theme_mod( 'responsive_buttons_mobile_bottom_padding', 10 ) );

	$buttons_radius       = esc_html( get_theme_mod( 'responsive_buttons_radius' ) );
	$buttons_border_width = esc_html( get_theme_mod( 'responsive_buttons_border_width', 0 ) );


	// Sub Menu Color.
	$header_sub_menu_background_color = esc_html( get_theme_mod( 'responsive_header_sub_menu_background_color', '#ffffff' ) );
	$header_sub_menu_link_color       = esc_html( get_theme_mod( 'responsive_header_sub_menu_link_color', '#333333' ) );
	$header_sub_menu_link_hover_color = esc_html( get_theme_mod( 'responsive_header_sub_menu_link_hover_color', '#10659C' ) );

	// Header Padding.
	$header_padding_right  = esc_html( get_theme_mod( 'responsive_header_right_padding' ) );
	$header_padding_left   = esc_html( get_theme_mod( 'responsive_header_left_padding' ) );
	$header_padding_top    = esc_html( get_theme_mod( 'responsive_header_top_padding' ) );
	$header_padding_bottom = esc_html( get_theme_mod( 'responsive_header_bottom_padding' ) );

	$header_tablet_padding_right  = esc_html( get_theme_mod( 'responsive_header_tablet_right_padding' ) );
	$header_tablet_padding_left   = esc_html( get_theme_mod( 'responsive_header_tablet_left_padding' ) );
	$header_tablet_padding_top    = esc_html( get_theme_mod( 'responsive_header_tablet_top_padding', 28 ) );
	$header_tablet_padding_bottom = esc_html( get_theme_mod( 'responsive_header_tablet_bottom_padding', 28 ) );

	$header_mobile_padding_right  = esc_html( get_theme_mod( 'responsive_header_mobile_right_padding' ) );
	$header_mobile_padding_left   = esc_html( get_theme_mod( 'responsive_header_mobile_left_padding' ) );
	$header_mobile_padding_top    = esc_html( get_theme_mod( 'responsive_header_mobile_top_padding', 28 ) );
	$header_mobile_padding_bottom = esc_html( get_theme_mod( 'responsive_header_mobile_bottom_padding', 28 ) );


	$custom_css .= '
		.widget-area {
			background-color: ' .$mf_sidebar_background_color . ';
			color: ' . $mf_sidebar_text_color . ';
		}

		.widget-area .widget-title{
			color: ' . $mf_sidebar_headings_color . ';
		}

		.widget-area a, .widget-area a:visited {
			color: ' . $mf_sidebar_link_color . ';
		}

		.widget-area a:hover {
			color: ' . $mf_sidebar_link_hover_color . ';
		}

		nav.main-panel.main-navigation .menu > ul li a, nav.main-panel.main-navigation ul.menu li a, .site-header .widget a {
			color: ' . $mf_header_menu_link_color . ';
		}

		.cta-content h2, .hero .hero-content h2 {
			color: ' . $mf_heading2_text_color . ';
		}

		.hero .hero-content h1 {
			color: ' . $mf_heading1_text_color . ';
		}

		.teaser .teaser-content h3 {
			color: ' . $mf_heading3_text_color . ';
		}

		.hero .hero-content .button, .cta .first-button, .cta .second-button {
			border-radius:' . $buttons_radius . 'px;
			padding: ' . responsive_spacing_css( $buttons_padding_top, $buttons_padding_right, $buttons_padding_bottom, $buttons_padding_left ) . ';
			background:' . $button_color . ';

		}

		.hero .hero-content .button a, .cta .first-button a, .cta .second-button a {
			color: ' . $button_text_color . ';
		}

		.entry-content p {
			color: ' . $body_text_color . ';
		}

		a:visited {
			color: ' . $link_color . ';
		}

		nav.main-panel.main-navigation .menu > ul > li > ul, nav.main-panel.main-navigation ul.menu > li > ul, nav.main-panel.main-navigation ul.menu > li > ul li ul {
			background-color: ' . $header_sub_menu_background_color . ';
		}

		nav.main-panel.main-navigation ul.menu li ul li a {
			color: ' . $header_sub_menu_link_color . ';
		}

		nav.main-panel.main-navigation ul.menu li ul li a:hover {
			color: ' . $header_sub_menu_link_hover_color . ';
		}

		.site-branding-wrapper {
			padding: ' . responsive_spacing_css( $header_padding_top, $header_padding_right, $header_padding_bottom, $header_padding_left ) . ';

		}
		@media screen and ( max-width: 992px ) {
			.site-branding-wrapper {
				padding: ' . responsive_spacing_css( $header_tablet_padding_top, $header_tablet_padding_right, $header_tablet_padding_bottom, $header_tablet_padding_left ) . ';
			}
		}
		@media screen and ( max-width: 576px ) {
			.site-branding-wrapper {
				padding: ' . responsive_spacing_css( $header_mobile_padding_top, $header_mobile_padding_right, $header_mobile_padding_bottom, $header_mobile_padding_left ) . ';
			}
		}

';

	wp_add_inline_style( 'mobile-friendly-style', apply_filters( 'responsive_head_css', $custom_css ) );

}
add_action( 'wp_enqueue_scripts', 'mobile_friendly_customizer_styles', 99 );
